/*
 * LDG plugin.
 * Copyright (c) 2004-2005 Zorro ( zorro270@yahoo.fr)
 *
 * This plugin is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This plugin is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 */


#include <codec\ldg\types2b.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tos.h>
#include <setjmp.h>



#ifdef __PUREC__
#define CDECL cdecl
#else
#include <compiler.h>
#define CDECL __CDECL
#endif


#ifndef TRUE
#define TRUE	1
#define FALSE	0
#endif

#ifndef MIN
#define MAX(a,b) ((a)>(b)?(a):(b))
#define MIN(a,b) ((a)<(b)?(a):(b))
#endif

#define M_EXIF			0xE1
#define UP_TO_DOWN 		0
#define DOWN_TO_UP		1
#define ST_RAM			0
#define TT_RAM			1
#define GOLBAL_ERROR	0
#define DSP_ERROR		1
#define PROGRESSIVE_JPG	2
#define ALL_OK			3

typedef struct _img_data {
	int16		imagecount;
	uint16		delay[1024];
	uint8		*image_buf[1024];
} img_data;


typedef struct _txt_data {
	int16		lines;				/* Number of lines in the text 					*/
	int16		max_lines_length;	/* The length of the greater line (in nbr char)	*/
	char	 	*txt[256];
} txt_data;


typedef struct {
	uint8	red;
	uint8	green;
	uint8	blue;
} COLOR_MAP;


typedef struct _img_info *IMGINFO;

typedef struct _img_info {
	/* Data returned by the decoder Picture's initialisation										size	offset */
	uint16    	width;					/* Picture width 											002		+0000 */
	uint16		height;					/* Picture Height											002		+0002 */
	uint16 		components;  			/* Picture components 										002		+0004 */
	uint16	 	planes;					/* Picture bits by pixel									002		+0006 */
	uint32 		colors;					/* Picture colors number									004		+0008 */
	int16		orientation;			/* picture orientation: UP_TO_DOWN or DONW_TO_UP ( ex: TGA)	002		+0012 */
	uint16		page;					/* Number of page/image in the file 						002		+0014 */
	uint16		delay;					/* Animation delay in 200th sec. between each frame.		002		+0016 */
	uint16		num_comments;			/* Lines in the file's comment. ( 0 if none) 	 			002		+0018 */
	uint16		max_comments_length;	/* The length of the greater line in the comment 			002		+0020 */
	int16		indexed_color;			/* Picture has a palette: 0) No 1) Yes						002		+0022 */
	int16		memory_alloc;			/* where to do the memory allocation for the reader_read
											 function buffer, possible values are ST_RAM or TT_RAM	002		+0024 */
	COLOR_MAP	palette[256];			/* Palette in standard RGB format							768		+0026 */


	/* data send to the codec */
	uint32		background_color;		/* The wanted background's color in hex						004		+1050 */
	int16		thumbnail;				/* 1 if true else 0.
											 Some format have thumbnail inside the picture, if 1, we
											 want only this thumbnail and not the image itself 		002		+1054 */
	uint16		page_wanted;			/* The wanted page to get for the reader_read() function
											 The first page is 0 and the last is img_info->page - 1	002		+1056 */


	/* The following variable are only for Information Purpose, the zview doesn't
		use it for decoding routine but only for the information dialog */
	char		info[40];				/* Picture's info, for ex: "Gif 87a" [lp]					040		+1058 */
	char		more[40];				/* extra picture info [lp]									040		+1098 */
	char		compression[30];		/* Compression type, ex: "LZW" [lp]							030		+1138 */
	uint16    	real_width;				/* Real picture width( if the thumbnail variable is 1)		002		+1168 */
	uint16		real_height;			/* Ral picture Height( if the thumbnail variable is 1)		002		+1170 */


	/* Private data for the plugin */
	void		*_priv_ptr;				/*															004		+1172 */
	void		*_priv_ptr_more;		/*															004		+1176 */
	void		*__priv_ptr_more;		/*															004		+1180 */

	int32		_priv_var;				/*															004		+1184 */
	int32		_priv_var_more;			/*															004		+1188 */
} img_info;								/*															total	 1192 */


/* lp - changed */
void	CDECL init( void);
int32	CDECL reader_init( const char *name, IMGINFO info);
int32	CDECL reader_read( IMGINFO info, uint8 *buffer);
int32	CDECL reader_quit( IMGINFO info);
void	CDECL reader_get_txt( IMGINFO info, txt_data *txtdata);
int32	CDECL encoder_init( const char *name, IMGINFO info);
int32	CDECL encoder_write( IMGINFO info, uint8 *buffer);
int32 	CDECL encoder_quit( IMGINFO info);


/* eof */
